@@ -122,7 +122,8 @@ sub POE::Kernel::CATCH_EXCEPTIONS () { 0 }
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 
 BEGIN {
-  package POE::Kernel;
+  package
+  POE::Kernel;
   use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
 }
 
